@@ -11,7 +11,7 @@ import wx.adv
 import calendar
 import operator
 from functools import reduce
-
+import dialogs
 
 class Val:
     pass
@@ -63,15 +63,14 @@ class Month_Cal(wx.adv.GenericCalendarCtrl):
         self.d_click = wx.DateTime()  # FromDMY(1, 0,2002)
 
     def OnLeftDown(self, event):
+        self.OnRightDown(event)
+
+    def OnRightDown(self, event):
         # HitTest(Point pos) -> (result, date, weekday)
-        res, d, w = self.HitTest(event.GetPosition())
-        if res == wx.adv.CAL_HITTEST_DAY:
-            Val.frame.SetStatusText(info(d))
-
-    def OnRightDown(self, event):
         res, d, w = self.HitTest(event.GetPosition())
         if res == wx.adv.CAL_HITTEST_DAY:
             # now d contain clicked day
+            Val.frame.SetStatusText(info(d))
             self.d_click = d
             menu = wx.Menu()
             menu.Append(1, d.Format('%d %B'))
@@ -119,7 +118,7 @@ class Month_Cal(wx.adv.GenericCalendarCtrl):
 
     def OnNote(self, event):
         txt = get_note(self.d_click)
-        dlg = Note_Dlg(self, self.d_click.Format('%d %B'), txt)
+        dlg = dialogs.Note_Dlg(self, self.d_click.Format('%d %B'), txt)
         ret = dlg.ShowModal()
         t = dlg.Get_Txt()
         dlg.Destroy()
@@ -206,7 +205,7 @@ class Cal_Year(wx.ScrolledWindow):
         w = box.GetSize().GetWidth()
         h = box.GetSize().GetHeight()
         Val.frame.SetClientSize(wx.Size(w+10, h+90))
-        self.SetScrollbars(20, 20, w/20, h/20)
+        self.SetScrollbars(20, 20, w//20, h//20)
 
     def Draw_Year(self):
         Val.frame.SetTitle(cycle.name+" - "+str(self.year))
@@ -377,7 +376,7 @@ def calc_fert(year):
         min, max = min_max(i)
         begin = d+wx.DateSpan.Days(min-18)  # begin fertile
         end = d+wx.DateSpan.Days(max-11)  # end fertile
-        ovul = end-wx.DateSpan.Days(((max-11)-(min-18))/2)  # day of ovul
+        ovul = end-wx.DateSpan.Days(((max-11)-(min-18))//2)  # day of ovul
         if year_b <= ovul <= year_e:
             add_mark(ovul, MARK_OVUL, year)
 
@@ -424,7 +423,7 @@ def calc_fert(year):
 
         begin = d+wx.DateSpan.Days(min-18)  #  
         end = d+wx.DateSpan.Days(max-11)  #  
-        ovul = end-wx.DateSpan.Days(((max-11)-(min-18))/2)  # day of ovul
+        ovul = end-wx.DateSpan.Days(((max-11)-(min-18))//2)  # day of ovul
         if year_b <= ovul <= year_e:
             add_mark(ovul, MARK_OVUL, year)
 
